@@ -1,4 +1,4 @@
-__version__ = '0.2.24'
+__version__ = "0.2.48"
 
 import functools
 import logging
@@ -17,8 +17,16 @@ class SQ_Blueprint(Blueprint):
             kwargs["import_name"] = __name__
         super().__init__(name=name, url_prefix=url_prefix, **kwargs)
 
-    def decorator_handler(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
-                          content_type: str = "json", methods=['POST'], export_enable: bool = False):
+    def decorator_handler(
+            self,
+            title: str,
+            url: str = None,
+            cache_enalbe: bool = False,
+            cache_ex: int = 3600 * 10,
+            content_type: str = "json",
+            methods=["POST"],
+            export_enable: bool = False,
+    ):
         options = {"methods": methods}
 
         def decorator(func):
@@ -41,9 +49,7 @@ class SQ_Blueprint(Blueprint):
                     # 如果没有开启缓存，或者缓存未命中，则执行原始函数
                     data = func(*args, **kwargs)
                 if isinstance(data, dict) and export_enable:
-                    data.update({
-                        "download_key": download_key
-                    })
+                    data.update({"download_key": download_key})
                 return data
 
             wrapper._title = title
@@ -54,12 +60,31 @@ class SQ_Blueprint(Blueprint):
 
         return decorator
 
-    def post_route(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
-                   content_type: str = "json", methods=['POST'], export_enable: bool = False):
-        decorator = self.decorator_handler(title, url, cache_enalbe, cache_ex, content_type, methods, export_enable)
+    def post_route(
+            self,
+            title: str,
+            url: str = None,
+            cache_enalbe: bool = False,
+            cache_ex: int = 3600 * 10,
+            content_type: str = "json",
+            methods=["POST"],
+            export_enable: bool = False,
+    ):
+        decorator = self.decorator_handler(
+            title, url, cache_enalbe, cache_ex, content_type, methods, export_enable
+        )
         return decorator
 
-    def get_route(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
-                  content_type: str = "json", methods=['GET']):
-        decorator = self.decorator_handler(title, url, cache_enalbe, cache_ex, content_type, methods)
+    def get_route(
+            self,
+            title: str,
+            url: str = None,
+            cache_enalbe: bool = False,
+            cache_ex: int = 3600 * 10,
+            content_type: str = "json",
+            methods=["GET"],
+    ):
+        decorator = self.decorator_handler(
+            title, url, cache_enalbe, cache_ex, content_type, methods
+        )
         return decorator
